@@ -69,6 +69,13 @@ REGISTRY = {
             "url": "https://github.com/fatiando-data/earth-topography-10arcmin/releases/download/v1",
         },
     },
+    "lightning-creek-magnetic-grid.nc": {
+        "v1": {
+            "hash": "md5:4b19c2eabe75865183964983861cbf68",
+            "doi": "doi:10.5281/zenodo.7079711",
+            "url": "https://github.com/fatiando-data/lightning-creek-magnetic-grid/releases/download/v1",
+        },
+    },
     "osborne-magnetic.csv.xz": {
         "v1": {
             "hash": "md5:b26777bdde2f1ecb97dda655c8b1cf71",
@@ -226,6 +233,10 @@ def fetch_alps_gps(version):
 
     **Original license:** CC-BY
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/alps-gps-velocity>`__
+
     **Versions:**
 
     * `1
@@ -276,6 +287,10 @@ def fetch_britain_magnetic(version):
 
     **Original license:** Open Government Licence
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/britain-magnetic>`__
+
     **Versions:**
 
     * `1
@@ -322,6 +337,10 @@ def fetch_british_columbia_lidar(version):
 
     **Original license:** Open Government Licence - British Columbia
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/british-columbia-lidar>`__
+
     **Versions:**
 
     * `1
@@ -370,6 +389,10 @@ def fetch_bushveld_gravity(version):
     domain <https://ngdc.noaa.gov/mgg/global/dem_faq.html#sec-2.4>`__
     (topography)
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/bushveld-gravity>`__
+
     **Versions:**
 
     * `1
@@ -415,6 +438,10 @@ def fetch_caribbean_bathymetry(version):
 
     **Original license:** Public domain
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/caribbean-bathymetry>`__
+
     **Versions:**
 
     * `1
@@ -461,6 +488,10 @@ def fetch_earth_geoid(version):
 
     **Original license:** CC-BY
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/earth-geoid-10arcmin>`__
+
     **Versions:**
 
     * `1
@@ -509,6 +540,10 @@ def fetch_earth_gravity(version):
 
     **Original license:** CC-BY
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/earth-gravity-10arcmin>`__
+
     **Versions:**
 
     * `1
@@ -554,6 +589,10 @@ def fetch_earth_topography(version):
 
     **Original license:** Public domain
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/earth-topography-10arcmin>`__
+
     **Versions:**
 
     * `1
@@ -576,6 +615,53 @@ def fetch_earth_topography(version):
     return Path(_repository(fname, version).fetch(fname))
 
 
+def fetch_lightning_creek_magnetic(version):
+    """
+    Magnetic anomaly grid of the Lightning Creek Sill Complex, Australia
+
+    This is a section of a survey acquired in 1990 by the Queensland
+    Government, Australia. The grid has 50 m resolution (UTM coordinates) and
+    is at a uniform orthometric height of 500 m. Total field anomalies are in
+    nT.
+
+    **Format:** netCDF4 with zlib compression
+
+    **Load with:** :func:`xarray.load_dataarray` (requires the `netcdf4
+    <https://github.com/Unidata/netcdf4-python>`__ library)
+
+    **Original source:** `Geophysical Acquisition & Processing Section 2019.
+    MIM Data from Mt Isa Inlier, QLD (P1029), magnetic line data, AWAGS
+    levelled. Geoscience Australia, Canberra
+    <http://pid.geoscience.gov.au/dataset/ga/142419>`__
+
+    **Original license:** CC-BY
+
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/lightning-creek-magnetic-grid>`__
+
+    **Versions:**
+
+    * `1
+      <https://github.com/fatiando-data/lightning-creek-magnetic-grid/releases/tag/v1>`_
+      (doi:`10.5281/zenodo.7079711 <https://doi.org/10.5281/zenodo.7079711>`__)
+
+    Parameters
+    ----------
+    version : int
+        The data version to fetch. See the available versions above.
+
+    Returns
+    -------
+    fname : :class:`pathlib.Path`
+        Path to the downloaded file on disk.
+
+    """
+    _check_versions(version, allowed={1}, name="Lightning Creek magnetic")
+    fname = "lightning-creek-magnetic-grid.nc"
+    return Path(_repository(fname, version).fetch(fname))
+
+
 def fetch_osborne_magnetic(version):
     """
     Magnetic airborne survey of the Osborne Mine and surroundings, Australia
@@ -603,6 +689,10 @@ def fetch_osborne_magnetic(version):
 
     **Original license:** CC-BY
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/osborne-magnetic>`__
+
     **Versions:**
 
     * `1
@@ -647,6 +737,10 @@ def fetch_sierra_negra_topography(version):
 
     **Original license:** CC-BY
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/sierra-negra-topography>`__
+
     **Versions:**
 
     * `1
@@ -692,6 +786,10 @@ def fetch_southern_africa_gravity(version):
 
     **Original license:** Public domain
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/southern-africa-gravity>`__
+
     **Versions:**
 
     * `1
@@ -731,6 +829,10 @@ def fetch_southern_africa_topography(version):
 
     **Original license:** Public domain
 
+    **Pre-processing:** `Source code for preparation of the original dataset
+    for redistribution in Ensaio
+    <https://github.com/fatiando-data/southern-africa-topography>`__
+
     **Versions:**
 
     * `1
